!ByteArray methodsFor: '*NetStrings' stamp: 'svp 12/3/2002 16:44'!
asInteger
	"This method answers the receiver's little endian integer representation"

	| answer |
	answer := LargePositiveInteger new: self size.
	answer replaceFrom: 1 to: self size with: self startingAt: 1.
	^answer normalize.
! !

!ByteArray methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 13:14'!
asNetString

	| strm |
	strm _ (ByteArray new: (self size + 5)) writeStream.
	self writeNetStringOn: strm.
	^strm contents! !

!Integer methodsFor: '*NetStrings' stamp: 'svp 12/3/2002 16:30'!
asNetString

	| strm |
	strm _ (ByteArray new: (self digitLength + 5)) writeStream.
	self writeNetStringOn: strm.
	^strm contents
! !

!String methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 16:43'!
asNetString

	| strm |
	strm _ (ByteArray new: (self size + 5)) writeStream.
	self writeNetStringOn: strm.
	^strm contents! !

!ByteArray methodsFor: '*NetStrings' stamp: 'svp 12/3/2002 16:25'!
asNetStringChars

	| strm |
	strm _ (String new: (self size + 5)) writeStream.
	self writeNetStringCharsOn: strm.
	^strm contents! !

!Integer methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 13:13'!
asNetStringChars

	| strm |
	strm _ (String new: (self digitLength + 5)) writeStream.
	self writeNetStringCharsOn: strm.
	^strm contents
! !

!String methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 16:43'!
asNetStringChars

	| strm |
	strm _ (String new: (self size + 5)) writeStream.
	self writeNetStringCharsOn: strm.
	^strm contents! !

!ByteArray class methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 13:18'!
readNetStringFrom: strm
	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See ByteArray>>writeNetStringOn: for this method's complement."

	| size answer |
	size _ strm readNetStringSize.
	answer := strm next: size.
	strm next. "Skip over the comma"
	^answer! !

!Integer class methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 13:21'!
readNetStringFrom: strm
	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See Integer>>writeNetStringOn: for this method's complement."

	| size answer |
	size := strm readNetStringSize.
	answer := (strm next: size) asInteger.
	strm next. "Skip over the comma"
	^answer! !

!String class methodsFor: '*NetStrings' stamp: 'svp 12/3/2002 16:28'!
readNetStringFrom: strm
	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See String>>writeNetStringOn: for this method's complement."

	| size answer |
	size := strm readNetStringSize.
	answer := (strm next: size) asString.
	strm next. "Skip over the comma"
	^answer! !

!ByteArray class methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 13:20'!
readNetStringFromChars: strm
	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See ByteArray>>writeNetStringOn: for this method's complement."

	| size answer |
	size _ strm readNetStringSizeFromChars.
	answer := (strm next: size) asByteArray.
	strm next. "Skip over the comma"
	^answer! !

!Integer class methodsFor: '*NetStrings' stamp: 'svp 12/3/2002 16:32'!
readNetStringFromChars: strm
	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See Integer>>writeNetStringCharsOn: for this method's complement."

	| size answer |
	size := strm readNetStringSizeFromChars.
	answer := (strm next: size) asByteArray asInteger.
	strm next. "Skip over the comma"
	^answer! !

!String class methodsFor: '*NetStrings' stamp: 'svp 12/3/2002 16:28'!
readNetStringFromChars: strm
	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See String>>writeNetStringOn: for this method's complement."

	| size answer |
	size := strm readNetStringSizeFromChars.
	answer := strm next: size.
	strm next. "Skip over the comma"
	^answer! !

!Stream methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 13:19'!
readNetStringSize

	| size byte |
	size _ 0.
	[(byte _ self next) = 58] whileFalse:
		[(byte < 48 or: [byte > 57]) ifTrue: [^self error: 'invalid net string'].
		size _ (size * 10) + (byte - 48)].
	^size! !

!Stream methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 17:32'!
readNetStringSizeFromChars

	| size char |
	size _ 0.
	[(char _ self next) = $:] whileFalse:
		[(char < $0 or: [char > $9]) ifTrue: [^self error: 'invalid net string'].
		size _ (size * 10) + (char asciiValue - 48)].
	^size! !

!ByteArray methodsFor: '*NetStrings' stamp: 'svp 12/3/2002 16:26'!
writeNetStringCharsOn: strm

	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See ByteArray class>>readNetStringFrom: for this method's complement."

	strm nextPutAll: self size printString.
	strm nextPut: $:.
	strm nextPutAll: self asString.
	strm nextPut: $,.! !

!Integer methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 16:39'!
writeNetStringCharsOn: strm
	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See Integer class>>readNetStringFrom: for this method's complement."

	| dl |
	dl _ self digitLength.
	strm nextPutAll: dl printString.
	strm nextPut: $:. 
	1 to: dl do: [ :in | strm nextPut: (Character value: (self digitAt: in)) ].
	strm nextPut: $,.

! !

!String methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 16:39'!
writeNetStringCharsOn: strm

	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See String class>>readNetStringFrom: for this method's complement."

	strm nextPutAll: self size printString.
	strm nextPut: $:.
	strm nextPutAll: self.
	strm nextPut: $,.! !

!ByteArray methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 16:40'!
writeNetStringOn: strm

	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See ByteArray class>>readNetStringFrom: for this method's complement."

	strm nextPutAll: self size printString asByteArray.
	strm nextPut: 58. "$: asciiValue"
	strm nextPutAll: self.
	strm nextPut: 44. "$, asciiValue"! !

!Integer methodsFor: '*NetStrings' stamp: 'svp 11/5/2002 16:40'!
writeNetStringOn: strm
	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See Integer class>>readNetStringFrom: for this method's complement."

	| dl |
	dl _ self digitLength.
	strm nextPutAll: dl printString asByteArray.
	strm nextPut: 58. "$: asciiValue"
	1 to: dl do: [ :in | strm nextPut: (self digitAt: in) ].
	strm nextPut: 44. "$, asciiValue"

! !

!String methodsFor: '*NetStrings' stamp: 'svp 11/4/2002 16:51'!
writeNetStringOn: strm

	"This method implements the NetString protocol as 
	defined by: http://cr.yp.to/proto/netstrings.txt"

	"See String class>>readNetStringFrom: for this method's complement."

	strm nextPutAll: self size printString asByteArray.
	strm nextPut: 58.  "$: asciiValue"
	strm nextPutAll: self asByteArray.
	strm nextPut: 44. "$, asciiValue"! !

Smalltalk at: #FilePackageManager ifPresent: [:p | p registerPackage: 'NetStrings'].!

